use anyhow::Error;
use bevy::asset::{AssetLoader, BoxedFuture, LoadContext, LoadedAsset};
use bevy::reflect::TypeUuid;
use serde::{Deserialize, Serialize};

use crate::world::Encounter;

pub struct EncounterSetJsonLoader;
pub struct EncounterSetTomlLoader;

#[derive(Debug, Default, Clone, TypeUuid, Serialize, Deserialize)]
#[uuid = "87953518-7969-11ed-9ec9-d7c0b4b5e357"]
pub struct EncounterSet {
	pub encounters: Vec<Encounter>,
}

impl EncounterSet {
	pub fn select(&self) -> Encounter {
		let val = fastrand::usize(0..self.encounters.len());
		self.encounters[val].clone()
	}
}

impl AssetLoader for EncounterSetJsonLoader {
	fn load<'a>(
		&'a self,
		bytes: &'a [u8],
		load_context: &'a mut LoadContext,
	) -> BoxedFuture<'a, anyhow::Result<(), Error>> {
		Box::pin(async move {
			let manifest: EncounterSet = serde_json::from_slice(bytes)?;
			load_context.set_default_asset(LoadedAsset::new(manifest));
			Ok(())
		})
	}

	fn extensions(&self) -> &[&str] {
		&["encounters.json"]
	}
}

impl AssetLoader for EncounterSetTomlLoader {
	fn load<'a>(
		&'a self,
		bytes: &'a [u8],
		load_context: &'a mut LoadContext,
	) -> BoxedFuture<'a, anyhow::Result<(), Error>> {
		Box::pin(async move {
			let manifest: EncounterSet = toml::from_slice(bytes)?;
			load_context.set_default_asset(LoadedAsset::new(manifest));
			Ok(())
		})
	}

	fn extensions(&self) -> &[&str] {
		&["encounters.toml"]
	}
}
