use std::collections::HashMap;

use anyhow::Error;
use bevy::asset::{AssetLoader, BoxedFuture, LoadContext, LoadedAsset};

use crate::world::{RosterEntry, TradeManifest};

pub struct TradeManifestJsonLoader;
pub struct TradeManifestTomlLoader;

impl AssetLoader for TradeManifestJsonLoader {
	fn load<'a>(
		&'a self,
		bytes: &'a [u8],
		load_context: &'a mut LoadContext,
	) -> BoxedFuture<'a, anyhow::Result<(), Error>> {
		Box::pin(async move {
			let manifest: TradeManifest = serde_json::from_slice(bytes)?;
			load_context.set_default_asset(LoadedAsset::new(manifest));
			Ok(())
		})
	}

	fn extensions(&self) -> &[&str] {
		&["manifest.json"]
	}
}

impl AssetLoader for TradeManifestTomlLoader {
	fn load<'a>(
		&'a self,
		bytes: &'a [u8],
		load_context: &'a mut LoadContext,
	) -> BoxedFuture<'a, anyhow::Result<(), Error>> {
		Box::pin(async move {
			let manifest: TradeManifest = toml::from_slice(bytes)?;
			load_context.set_default_asset(LoadedAsset::new(manifest));
			Ok(())
		})
	}

	fn extensions(&self) -> &[&str] {
		&["manifest.toml"]
	}
}
