mod apack_handler;
mod asset_types;
mod loader;
mod resources;
mod startup;

pub use asset_types::encounter_set::EncounterSet;
pub use asset_types::ldtk_project::{LdtkLoader, LdtkProject, LevelIndex, TilesetIndex};
use bevy::app::{App, Plugin};
use bevy::prelude::AddAsset;
use iyes_loopless::condition::ConditionSet;
use iyes_loopless::prelude::AppLooplessStateExt;
pub use loader::AssetTypeLoader;
pub use resources::{AssetHandles, AssetNameMapping, FixedAssetNameMapping, SpriteSheetConfig};

use crate::assets::apack_handler::handle_apack_process_events;
use crate::assets::asset_types::encounter_set::{EncounterSetJsonLoader, EncounterSetTomlLoader};
use crate::assets::asset_types::ldtk_project::handle_ldtk_project_events;
use crate::assets::asset_types::trade_manifest::{
	TradeManifestJsonLoader, TradeManifestTomlLoader,
};
use crate::system::flow::AppState;
use crate::world::TradeManifest;

pub struct AssetsPlugin;
impl Plugin for AssetsPlugin {
	fn build(&self, app: &mut App) {
		app.init_resource::<AssetHandles>()
			.init_resource::<LevelIndex>()
			.init_resource::<TilesetIndex>()
			.add_asset::<LdtkProject>()
			.add_asset::<TradeManifest>()
			.add_asset::<EncounterSet>()
			.add_asset_loader(LdtkLoader)
			.add_asset_loader(TradeManifestJsonLoader)
			.add_asset_loader(TradeManifestTomlLoader)
			.add_asset_loader(EncounterSetJsonLoader)
			.add_asset_loader(EncounterSetTomlLoader)
			.add_enter_system(AppState::Preload, startup::start_preload_resources)
			.add_enter_system(AppState::Preload, startup::start_load_resources)
			.add_system(handle_apack_process_events)
			.add_system(handle_ldtk_project_events)
			.add_system_set(
				ConditionSet::new()
					.run_in_state(AppState::Setup)
					.with_system(startup::check_load_resources)
					.into(),
			);
	}
}
