use bevy::asset::LoadState;
use bevy::prelude::*;
use iyes_loopless::prelude::NextState;

use crate::assets::AssetTypeLoader;
use crate::system::flow::AppState;

pub fn start_preload_resources(mut commands: Commands) {
	// TODO: Add preload commands here

	commands.insert_resource(NextState(AppState::Setup))
}

pub fn start_load_resources(mut loader: AssetTypeLoader) {
	loader.load_images(&[("splash.png", "splash")]);
	loader.load_audio(&[("splash_sting.mp3", "splash_sting")]);
	loader.load_apack(&[("resources.apack", "resources")]);
	loader.load_trade_manifest(&[
		("trade_manifests/whitestone.manifest.toml", "whitestone"),
		("trade_manifests/monastery.manifest.toml", "monastery"),
		("trade_manifests/ship.manifest.toml", "ship"),
	]);
	loader.load_encounter_set(&[("encounters/grasslands.encounters.toml", "grasslands")]);
}

pub fn check_load_resources(mut commands: Commands, loader: AssetTypeLoader) {
	let load_states = loader.get_all_load_state();

	if loader.check_apack_process_status() {
		log::info!("Assets loaded successfully");
		commands.insert_resource(NextState(AppState::Splash))
	}
}
