use std::time::Duration;

use bevy::input::Input;
use bevy::prelude::{Commands, Component, KeyCode, Res};
use iyes_loopless::state::NextState;
use micro_musicbox::prelude::{AudioEasing, AudioTween, MusicBox};

use crate::assets::AssetHandles;
use crate::system::flow::AppState;

#[derive(Component, Debug, Default, Copy, Clone)]
pub struct Player;

pub fn on_enter_game(mut musicbox: MusicBox<AssetHandles>) {
	musicbox.fade_in_music(
		"bgm",
		AudioTween::new(Duration::from_secs(2), AudioEasing::Linear),
	);
}

pub fn on_leave_game(mut musicbox: MusicBox<AssetHandles>) {
	musicbox.fade_out_music(AudioTween::new(Duration::from_secs(2), AudioEasing::Linear));
}

pub fn quit_game(mut commands: Commands, input: Res<Input<KeyCode>>) {
	if input.just_released(KeyCode::Escape) {
		commands.insert_resource(NextState(AppState::Menu));
	}
}
