use bevy::app::{App, Plugin};
use iyes_loopless::prelude::{AppLooplessStateExt, ConditionSet};

use crate::states::menu_state::go_to_game;
use crate::system::flow::AppState;

mod debug_state;
mod game_state;
mod menu_state;

pub struct StatesPlugin;
impl Plugin for StatesPlugin {
	fn build(&self, app: &mut App) {
		app.add_enter_system(AppState::Menu, menu_state::spawn_menu_entities)
			.add_exit_system(AppState::Menu, menu_state::despawn_menu_entities)
			.add_enter_system(AppState::InGame, game_state::on_enter_game)
			.add_exit_system(AppState::InGame, game_state::on_leave_game)
			.add_system_set(
				ConditionSet::new()
					.run_in_state(AppState::Menu)
					.with_system(go_to_game)
					.into(),
			)
			.add_system_set(
				ConditionSet::new()
					.run_in_state(AppState::InGame)
					.with_system(quit_game)
					.into(),
			)
			.insert_resource(debug_state::DebugStatus::Off)
			.add_system(debug_state::toggle_debug_mode)
			.add_system_set(
				ConditionSet::new()
					.run_in_state(AppState::InGame)
					.run_if_resource_equals(debug_state::DebugStatus::On)
					.with_system(debug_state::handle_debug_snapshots)
					.with_system(debug_state::show_zone_shapes)
					.into(),
			);
	}
}

pub use game_state::Player;

use crate::states::game_state::quit_game;
