use bevy::prelude::*;
use kayak_ui::prelude::{
	ComputedStyles, KStyle, KayakWidgetContext, RenderCommand, StyleProp, Widget,
};

use crate::basic_widget;
use crate::ui::prelude::{px, stretch, value};

#[derive(Component, Debug, Clone, PartialEq)]
pub struct HDividerWidgetProps {
	pub width: f32,
	pub padding: f32,
	pub color: Color,
}

impl Default for HDividerWidgetProps {
	fn default() -> Self {
		Self {
			width: 1.0,
			padding: 5.0,
			color: Color::ANTIQUE_WHITE,
		}
	}
}

impl Widget for HDividerWidgetProps {}

basic_widget!(HDividerWidgetProps => HDividerWidget);

pub fn render_h_divider(
	In((_, entity)): In<(KayakWidgetContext, Entity)>,
	_: Commands,
	mut query: Query<(&HDividerWidgetProps, &KStyle, &mut ComputedStyles)>,
) -> bool {
	if let Ok((props, style, mut computed)) = query.get_mut(entity) {
		*computed = KStyle {
			render_command: value(RenderCommand::Quad),
			background_color: StyleProp::Value(props.color),
			width: px(props.width),
			left: px(props.padding),
			right: px(props.padding),
			height: stretch(1.0),
			..Default::default()
		}
		.with_style(style)
		.into();
	}
	true
}
