use bevy::prelude::*;
use kayak_ui::prelude::{
	ComputedStyles, KStyle, KayakWidgetContext, RenderCommand, StyleProp, Widget,
};

use crate::basic_widget;
use crate::ui::prelude::{px, stretch, value};

#[derive(Component, Debug, Clone, PartialEq)]
pub struct VDividerWidgetProps {
	pub height: f32,
	pub padding: f32,
	pub color: Color,
}

impl Default for VDividerWidgetProps {
	fn default() -> Self {
		Self {
			height: 1.0,
			padding: 5.0,
			color: Color::ANTIQUE_WHITE,
		}
	}
}

impl Widget for VDividerWidgetProps {}

basic_widget!(VDividerWidgetProps => VDividerWidget);

pub fn render_v_divider(
	In((_, entity)): In<(KayakWidgetContext, Entity)>,
	_: Commands,
	mut query: Query<(&VDividerWidgetProps, &KStyle, &mut ComputedStyles)>,
) -> bool {
	if let Ok((props, style, mut computed)) = query.get_mut(entity) {
		*computed = KStyle {
			render_command: value(RenderCommand::Quad),
			background_color: StyleProp::Value(props.color),
			height: px(props.height),
			top: px(props.padding),
			bottom: px(props.padding),
			width: stretch(1.0),
			..Default::default()
		}
		.with_style(style)
		.into();
	}
	true
}
