use bevy::prelude::*;
use kayak_ui::prelude::*;

use crate::{empty_props, parent_widget};

#[derive(Copy, Clone, Default, Debug, Eq, PartialEq)]
pub enum MainMenuView {
	MenuPanel,
	TipsPanel,
	SettingsPanel,
	#[default]
	None,
}
impl MainMenuView {
	pub fn is_none(&self) -> bool {
		self == &MainMenuView::None
	}
}

#[derive(Copy, Clone, Default, Debug, Component, Eq, PartialEq)]
pub struct MainMenuContext {
	pub view: MainMenuView,
	pub next: Option<MainMenuView>,
}

impl MainMenuContext {
	pub fn new() -> Self {
		Self {
			view: MainMenuView::MenuPanel,
			next: None,
		}
	}

	pub fn next(&mut self, next: MainMenuView) {
		self.view = next;
		// self.view = MainMenuView::None;
		// self.next = Some(next);
	}

	fn cycle(&mut self) {
		if let Some(next) = self.next {
			self.view = next;
			self.next = None;
		}
	}
}

empty_props!(MainMenuContextProps);
parent_widget!(MainMenuContextProps => MainMenuContextProvider);

pub fn render_main_menu_context_provider(
	In((mut widget_context, entity)): In<(KayakWidgetContext, Entity)>,
	mut commands: Commands,
	mut children_query: Query<(&KStyle, &mut ComputedStyles, &KChildren)>,
	mut context_query: Query<&mut MainMenuContext>,
) -> bool {
	if let Ok((style, mut computed, children)) = children_query.get_mut(entity) {
		*computed = ComputedStyles(style.clone());
		if let Some(context_entity) = widget_context.get_context_entity::<MainMenuContext>(entity) {
			children.process(&mut widget_context, Some(entity));
		} else {
			let context_entity = commands.spawn(MainMenuContext::new()).id();
			widget_context.set_context_entity::<MainMenuContext>(Some(entity), context_entity);
		}
	}

	true
}
