use bevy::prelude::*;
use kayak_ui::prelude::*;
use kayak_ui::widgets::{ElementBundle, KayakAppBundle, TextProps, TextWidgetBundle};

use crate::system::utilities::format_ui_distance;
use crate::ui::components::*;
use crate::ui::prelude::{px, stretch, value};
use crate::ui::sync::UITravelInfo;
use crate::ui::utilities::context::create_root_context;
use crate::ui::utilities::StateUIRoot;
use crate::ui::widgets::*;
use crate::world::EncounterState;
use crate::{
	empty_props, parent_widget, register_widget_with_many_resources, register_widget_with_resource,
};

empty_props!(InGameProps);
parent_widget!(InGameProps => InGameLayout);

pub fn render_game_panels(
	In((widget_context, entity)): In<(KayakWidgetContext, Entity)>,
	mut commands: Commands,
	ui_data: Res<UITravelInfo>,
	encounter_state: Res<EncounterState>,
) -> bool {
	let parent_id = Some(entity);

	let distance_style = KStyle {
		position_type: value(KPositionType::SelfDirected),
		top: stretch(1.0),
		left: stretch(1.0),
		right: stretch(1.0),
		bottom: px(50.0),
		height: px(50.0),
		width: stretch(0.6),
		max_width: px(200.0),
		padding: value(Edge::all(Units::Stretch(1.0))),
		..Default::default()
	};

	let show_distance_panel = !encounter_state.is_in_encounter()
		&& !ui_data.is_in_town
		&& ui_data.distance_remaining > 0.1;

	rsx! {
		<ElementBundle>
			{ if show_distance_panel {
				constructor! {
					<PanelWidget styles={distance_style}>
						<TextWidgetBundle
							text={TextProps {
								content: format_ui_distance(ui_data.distance_remaining),
								size: 40.0,
								..Default::default()
							}}
							styles={KStyle {
								color: value(Color::BLACK),
								bottom: px(6.0),
								..Default::default()
							}}
						/>
					</PanelWidget>
				}
			}}

			{if ui_data.is_in_town {
				constructor! {
					<TownMenuPanel />
				}
			}}

			{if encounter_state.is_in_encounter() {
				constructor! {
					<EncounterPanel />
				}
			}}

			{ if show_distance_panel {
				constructor! {
					<StatsPanel />
				}
			}}
		</ElementBundle>
	};

	true
}

pub fn render_in_game_ui(mut commands: Commands) {
	let parent_id = None;
	let mut widget_context = create_ingame_context();

	rsx! {
		<KayakAppBundle>
			<InGameLayout />
		</KayakAppBundle>
	};

	commands.spawn((UICameraBundle::new(widget_context), StateUIRoot));
}

fn create_ingame_context() -> KayakRootContext {
	let mut widget_context = create_root_context();

	register_widget_with_many_resources!(
		widget_context,
		InGameProps,
		EmptyState,
		render_game_panels,
		uitravelinfo: UITravelInfo,
		encounterstate: EncounterState
	);

	widget_context
}
