use bevy::prelude::*;

use crate::states::Player;
use crate::world::{DistanceTravelled, HungerState, TradingState};

#[derive(Resource, Debug, Default, Copy, Clone)]
pub struct UIStatsData {
	pub money: usize,
	pub distance_travelled: f32,
	pub sustenance: usize,
}

pub fn sync_player_stats_info_to_ui(
	player_query: Query<(&DistanceTravelled, &TradingState, &HungerState), With<Player>>,
	mut ui_info: ResMut<UIStatsData>,
) {
	if let Ok((distance, trading, hunger)) = player_query.get_single() {
		if ui_info.money != trading.gold.max(0) as usize {
			ui_info.money = trading.gold.max(0) as usize;
		}

		if ui_info.distance_travelled != distance.0 {
			ui_info.distance_travelled = distance.0;
		}

		if ui_info.sustenance != hunger.sustenance {
			ui_info.sustenance = hunger.sustenance;
		}
	}
}
