use bevy::math::Vec3Swizzles;
use bevy::prelude::*;

use crate::states::Player;
use crate::world::{CurrentResidence, MapQuery, TownPaths, TravelPath};

#[derive(Resource, Clone, Default)]
pub struct UITravelInfo {
	pub distance_remaining: f32,
	pub is_in_town: bool,
	pub travel_options: Vec<(String, f32)>,
	pub current_town: Option<String>,
}

pub fn sync_player_travel_info_to_ui(
	player_query: Query<(&Transform, Option<&TravelPath>, &CurrentResidence), With<Player>>,
	mut ui_info: ResMut<UITravelInfo>,
	places: Res<TownPaths>,
	map_query: MapQuery,
) {
	for (transform, maybe_path, residence) in &player_query {
		if let Some(path) = maybe_path {
			let remaining_distance = path.ui_distance_remaining();
			let current_edge_length = path.get_current_edge_distance();
			let distance_to_next = path.distance_to_next_node(transform.translation.xy());

			ui_info.distance_remaining =
				remaining_distance - (current_edge_length - distance_to_next);
		}
		match residence {
			CurrentResidence::TravellingFrom(place) => {
				if ui_info.is_in_town {
					ui_info.current_town = None;
					ui_info.is_in_town = false;
				}
			}
			CurrentResidence::RestingAt(place) => {
				if !ui_info.is_in_town {
					ui_info.is_in_town = true;
					ui_info.current_town = Some(place.clone());
					let level = map_query.get_active_level().unwrap();
					let destinations = places.routes.get(place).unwrap();
					ui_info.travel_options = destinations
						.routes
						.iter()
						.map(|(loc, route)| (loc.clone(), route.calculate_distance(level)))
						.collect();
				}
			}
		}
	}
}
