use bevy::prelude::*;
use iyes_loopless::prelude::NextState;
use kayak_ui::prelude::*;
use kayak_ui::widgets::{ElementBundle, KImage, KImageBundle, TextProps, TextWidgetBundle};

use crate::assets::AssetHandles;
use crate::persistance::{fs_utils, LoadFileEvent};
use crate::system::flow::AppState;
use crate::ui::components::*;
use crate::ui::context::{MainMenuContext, MainMenuView};
use crate::ui::prelude::{pct, px, stretch, value};
use crate::ui::widgets::*;
use crate::{basic_widget, empty_props, on_button_click};

empty_props!(MainMenuPanelProps);
basic_widget!(MainMenuPanelProps => MainMenuPanel);

pub fn render_main_menu_panel(
	In((widget_context, entity)): In<(KayakWidgetContext, Entity)>,
	mut commands: Commands,
	mut props_query: Query<&mut ComputedStyles>,
	assets: Res<AssetHandles>,
) -> bool {
	let parent_id = Some(entity);
	let has_autosave = fs_utils::has_auto_save();

	let contents_container_style = KStyle {
		position_type: value(KPositionType::SelfDirected),
		width: pct(65.0),
		height: pct(80.0),
		min_width: px(400.0),
		min_height: px(300.0),
		max_width: px(500.0),
		max_height: px(400.0),
		top: stretch(1.0),
		left: stretch(1.0),
		right: stretch(1.0),
		bottom: stretch(1.0),
		layout_type: value(LayoutType::Column),
		row_between: px(20.0),
		..Default::default()
	};

	let header_style = KStyle {
		left: stretch(1.0),
		right: stretch(1.0),
		..Default::default()
	};

	let button_style = KStyle {
		width: px(300.0),
		left: stretch(1.0),
		right: stretch(1.0),
		..Default::default()
	};

	let on_new = on_button_click!(Commands, |mut commands: Commands| {
		commands.insert_resource(NextState(AppState::InGame));
	});
	let on_tips = on_button_click!(Commands, |mut commands: Commands| {
		commands.insert_resource(NextState(AppState::Tips));
	});
	let on_settings = on_button_click!(Commands, |mut commands: Commands| {
		commands.insert_resource(NextState(AppState::Settings));
	});
	let on_continue = on_button_click!(EventWriter<LoadFileEvent>, |mut events: EventWriter<
		LoadFileEvent,
	>| {
		events.send(LoadFileEvent::autosave());
	});

	rsx! {
		<ElementBundle styles={contents_container_style}>
			<TextWidgetBundle
				text={TextProps {
					content: String::from("Trader Tales"),
					font: Some(String::from("header")),
					size: 72.0,
					..Default::default()
				}}
				styles={header_style}
			/>

			<ButtonWidget
				styles={button_style.clone()}
				props={ButtonWidgetProps {
					text: String::from("New Game"),
					font_size: 32.0,
					..Default::default()
				}}
				on_event={on_new}
			/>

			<ButtonWidget
				styles={button_style.clone()}
				props={ButtonWidgetProps {
					text: String::from("Continue Game"),
					font_size: 32.0,
					is_disabled: !has_autosave,
					..Default::default()
				}}
				on_event={on_continue}
			/>
			<ButtonWidget
				styles={button_style.clone()}
				props={ButtonWidgetProps {
					text: String::from("Tips"),
					font_size: 32.0,
					..Default::default()
				}}
				on_event={on_tips}
			/>
			<ButtonWidget
				styles={button_style.clone()}
				props={ButtonWidgetProps {
					text: String::from("Settings"),
					font_size: 32.0,
					..Default::default()
				}}
				on_event={on_settings}
			/>
		</ElementBundle>
	};

	true
}
