use bevy::prelude::*;
use kayak_ui::prelude::*;
use kayak_ui::widgets::{BackgroundBundle, ElementBundle, TextProps, TextWidgetBundle};

use crate::system::utilities::format_ui_distance;
use crate::ui::sync::UIStatsData;
use crate::ui::{components::*, prelude::*, widgets::*};
use crate::{basic_widget, empty_props};

empty_props!(StatsPanelProps);
basic_widget!(StatsPanelProps => StatsPanel);

pub fn render_stats_panel(
	In((widget_context, entity)): In<(KayakWidgetContext, Entity)>,
	mut commands: Commands,
	ui_data: Res<UIStatsData>,
) -> bool {
	let parent_id = Some(entity);

	let root_style = KStyle {
		top: px(20.0),
		left: px(20.0),
		right: stretch(1.0),
		bottom: stretch(1.0),
		height: px(160.0),
		width: px(160.0),
		layout_type: value(LayoutType::Column),
		position_type: value(KPositionType::SelfDirected),
		..Default::default()
	};
	//
	let distance_travelled = format_ui_distance(ui_data.distance_travelled);

	let inner_container_style = KStyle {
		height: px(60.0),
		padding: edge_px(5.0),
		col_between: px(5.0),
		left: stretch(1.0),
		right: stretch(1.0),
		layout_type: value(LayoutType::Row),
		..Default::default()
	};

	let pad_style = KStyle {
		render_command: value(RenderCommand::Quad),
		height: px(20.0),
		..Default::default()
	};

	rsx! {
		<PanelWidget styles={root_style}>
			<PanelStatWidget props={PanelStatProps { fill: true, text: distance_travelled, font_size: 24.0, icon: IconContent::Atlas(String::from("icons"), 14), color: Color::BLACK }} />
			<ElementBundle styles={pad_style.clone()} />
			<PanelStatWidget props={PanelStatProps { fill: true, text: format!("{}g", ui_data.money), font_size: 24.0, icon: IconContent::Atlas(String::from("icons"), 8), color: Color::BLACK }} />
			<ElementBundle styles={pad_style} />
			<PanelStatWidget props={PanelStatProps { fill: true, text:  format!("{}", ui_data.sustenance), font_size: 24.0, icon: IconContent::Atlas(String::from("icons"), 15), color: Color::BLACK }} />
		</PanelWidget>
	};

	true
}
