use bevy::prelude::*;
use kayak_ui::prelude::*;
use kayak_ui::widgets::{
	ElementBundle, ScrollBoxBundle, ScrollBoxProps, ScrollContextProviderBundle, TextProps,
	TextWidgetBundle,
};

use crate::assets::AssetHandles;
use crate::states::Player;
use crate::system::utilities::format_ui_distance;
use crate::ui::components::*;
use crate::ui::prelude::*;
use crate::ui::sync::UITravelInfo;
use crate::ui::widgets::*;
use crate::world::{CurrentResidence, MapQuery, TownPaths};
use crate::{basic_widget, empty_props, on_button_click};

empty_props!(TransitPanelProps);
basic_widget!(TransitPanelProps => TransitPanel);

pub fn transit_button_factory(target: String) -> OnEvent {
	let target = target.clone();
	on_button_click!(
		ParamSet<(
			Commands,
			Res<TownPaths>,
			Query<(Entity, &CurrentResidence), With<Player>>,
			MapQuery,
		)>,
		|mut params: ParamSet<(
			Commands,
			Res<TownPaths>,
			Query<(Entity, &CurrentResidence), With<Player>>,
			MapQuery,
		)>| {
			let target = target.clone();
			let (entity, current) = {
				match params.p2().get_single() {
					Ok((entity, current)) => (entity.clone(), (current.get_location()).clone()),
					_ => return,
				}
			};

			let places = match params.p1().routes.get(&current) {
				Some(places) => places.clone(),
				None => return,
			};

			let bundle = match params.p3().get_active_level() {
				Some(level) => places.create_route_bundle_for(target, level).unwrap(),
				None => return,
			};

			params.p0().entity(entity).insert(bundle);
		}
	)
}

pub fn render_transit_panel(
	In((widget_context, entity)): In<(KayakWidgetContext, Entity)>,
	mut commands: Commands,
	ui_data: Res<UITravelInfo>,
	query: Query<&TransitPanelProps>,
) -> bool {
	let parent_id = Some(entity);

	if let Ok(props) = query.get(entity) {
		rsx! {
			<ElementBundle>
				<TextWidgetBundle
					text={TextProps {
						content: format!("Set off for:"),
						size: 32.0,
						..Default::default()
					}}
					styles={KStyle {
						color: value(Color::BLACK),
						padding: edge_px(20.0),
						bottom: px(15.0),
						left: stretch(1.0),
						right: stretch(1.0),
						..Default::default()
					}}
				/>
				<ScrollContextProviderBundle>
					<ScrollBoxBundle>
						{
							for (place, distance) in ui_data.travel_options.iter() {
								constructor! {
									<ButtonWidget
										styles={
											KStyle {
												left: stretch(1.0),
												right: stretch(1.0),
												width: pct(70.0),
												min_width: px(300.0),
												max_width: px(600.0),
												bottom: px(10.0),
												padding_left: px(20.0),
												padding_right: px(20.0),
												..Default::default()
											}
										}
										props={ButtonWidgetProps::text(format!("{}: {}", &place, format_ui_distance(*distance)), 28.0)}
										on_event={transit_button_factory(place.clone())}
									/>
								};
							}
						}
					</ScrollBoxBundle>
				</ScrollContextProviderBundle>
			</ElementBundle>
		};
	}

	true
}
