use bevy::prelude::*;
use bevy::render::render_resource::{Extent3d, TextureDimension, TextureFormat};
use bevy::render::texture::{BevyDefault, TextureFormatPixelInfo};
use fastrand::Rng;

use crate::system::utilities::Indexer;
use crate::world::generators::generate_overworld::{generate_overworld, WorldTileType};

pub fn generate_and_spawn_world(mut commands: Commands, mut images: ResMut<Assets<Image>>) {
	let world = generate_overworld(300, 300, Rng::new());
	let format = TextureFormat::bevy_default();

	let mut img = Image::new_fill(
		Extent3d {
			height: 300,
			width: 300,
			depth_or_array_layers: 1,
		},
		TextureDimension::D2,
		vec![100; format.pixel_size()].as_slice(),
		TextureFormat::bevy_default(),
	);

	log::info!("DOING IT");
	log::info!("{:?}", format.describe());

	let mut write_pixel = |index: usize, data: &[u8; 4]| {
		img.data[index * format.pixel_size()] = data[0];
		img.data[index * format.pixel_size() + 1] = data[1];
		img.data[index * format.pixel_size() + 2] = data[2];
		if format.pixel_size() == 4 {
			img.data[index * format.pixel_size() + 3] = data[3];
		}
	};

	for (index, tile) in world.terrain.iter().enumerate() {
		match tile {
			WorldTileType::Water => write_pixel(index, &[30, 144, 255, 255]),
			WorldTileType::Sand => write_pixel(index, &[255, 255, 224, 255]),
			WorldTileType::Dirt => write_pixel(index, &[165, 42, 42, 255]),
			WorldTileType::Grass => write_pixel(index, &[34, 139, 34, 255]),
			WorldTileType::Mountain => write_pixel(index, &[105, 105, 105, 255]),
			WorldTileType::Swamp => write_pixel(index, &[75, 0, 130, 255]),
			WorldTileType::Snow => write_pixel(index, &[240, 255, 255, 255]),
			WorldTileType::Desert => write_pixel(index, &[240, 230, 140, 255]),
		}
	}

	let handle = images.add(img);
	commands.spawn(SpriteBundle {
		texture: handle,
		transform: Transform::from_xyz(0.0, 0.0, 100.0),
		..Default::default()
	});
}
