use fastrand::Rng;
use num_traits::AsPrimitive;

use crate::system::utilities::Indexer;
use crate::world::generators::generate_overworld::WorldTileType;

pub mod debug_gen;
mod generate_overworld;
pub mod handle_overworld;
mod particle_rolling;

pub trait WorldGenerator {
	fn generate(&self, indexer: &Indexer, rng: &Rng) -> Vec<WorldTileType>;
	fn map_noise_value(noise: impl AsPrimitive<f64>) -> WorldTileType {
		let noise = noise.as_();
		if noise < 0.1 {
			WorldTileType::Water
		} else if noise < 0.2 {
			WorldTileType::Sand
		} else if noise < 0.6 {
			WorldTileType::Grass
		} else if noise < 0.8 {
			WorldTileType::Snow
		} else {
			WorldTileType::Mountain
		}
	}
}

pub use self::particle_rolling::ParticleRollingGenerator;
